@@ -44,6 +44,8 @@ import pickle  # pkg_resources,
 import pyTEMlib.file_tools as ft
 from pyTEMlib.config_dir import data_path
 
+from sidpy.base.num_utils import get_slope
+
 major_edges = ['K1', 'L3', 'M5', 'N5']
 all_edges = ['K1', 'L1', 'L2', 'L3', 'M1', 'M2', 'M3', 'M4', 'M5', 'N1', 'N2', 'N3', 'N4', 'N5', 'N6', 'N7', 'O1', 'O2',
              'O3', 'O4', 'O5', 'O6', 'O7', 'P1', 'P2', 'P3']
@@ -109,7 +111,6 @@ def read_dm3_eels_info(original_metadata):
         if 'Name' in exp_dictionary['Microscope Info']:
             experiment['microscope'] = exp_dictionary['Microscope Info']['Name']
 
-
     if 'number_of_frames' not in experiment:
         experiment['number_of_frames'] = 1
     if 'exposure_time' not in experiment:
@@ -127,7 +128,7 @@ def set_previous_quantification(current_dataset):
     for key in current_channel:
         if 'Log' in key:
             if current_channel[key]['analysis'][()] == 'EELS_quantification':
-                current_dataset.metadata.update(ft.nest_dict(current_channel[key].attrs))
+                current_dataset.metadata.update((current_channel[key].attrs))   # ToDo: find red dictionary
                 found_metadata = True
                 print('found previous quantification')
 
@@ -223,7 +224,7 @@ def fit_peaks(spectrum, energy_scale, pin, start_fit, end_fit, only_positive_int
     end_fit: int
         channel where fit starts
     only_positive_intensity: boolean
-        allows only for positive amplitueds if True; default = False)
+        allows only for positive amplitudes if True; default = False
 
     Returns
     -------
@@ -239,7 +240,6 @@ def fit_peaks(spectrum, energy_scale, pin, start_fit, end_fit, only_positive_int
     pin_flat = [item for sublist in pin for item in sublist]
     [p_out, _] = leastsq(residuals_ll, np.array(pin_flat), ftol=1e-3, args=(fit_energy, fit_spectrum,
                                                                             only_positive_intensity))
-
     p = []
     for i in range(len(pin)):
         if only_positive_intensity:
@@ -254,17 +254,17 @@ def fit_peaks(spectrum, energy_scale, pin, start_fit, end_fit, only_positive_int
 
 
 def get_x_sections(z=0):
-    """Reads X-ray fluorescent cross sections from a pickle file.
+    """Reads X-ray fluorescent cross-sections from a pickle file.
 
     Parameters
     ----------
     z: int
-        atomic number if zero all cross sections will be returned
+        atomic number if zero all cross-sections will be returned
 
     Returns
     -------
     dictionary
-        cross section of a element or of all elements if z = 0
+        cross-section of an element or of all elements if z = 0
 
     """
     pkl_file = open(data_path + '/edges_db.pkl', 'rb')
@@ -396,8 +396,8 @@ def find_all_edges(edge_onset, maximal_chemical_shift=5):
 def second_derivative(dataset, sensitivity):
     """Calculates second derivative of a sidpy.dataset"""
 
-    dim = ft.get_dimensions_by_type('spectral', dataset)
-    energy_scale = np.array(dim[0][1])
+    dim = dataset.get_spectrum_dims()
+    energy_scale = np.array(dataset._axes[dim[0]])
     if dataset.data_type.name == 'SPECTRAL_IMAGE':
         spectrum = dataset.view.get_spectrum()
     else:
@@ -405,7 +405,7 @@ def second_derivative(dataset, sensitivity):
 
     spec = scipy.ndimage.gaussian_filter(spectrum, 3)
 
-    dispersion = ft.get_slope(energy_scale)
+    dispersion = get_slope(energy_scale)
     second_dif = np.roll(spec, -3) - 2 * spec + np.roll(spec, +3)
     second_dif[:3] = 0
     second_dif[-3:] = 0
@@ -431,8 +431,8 @@ def second_derivative(dataset, sensitivity):
 def find_edges(dataset, sensitivity=2.5):
     """find edges within a sidpy.Dataset"""
 
-    dim = ft.get_dimensions_by_type('spectral', dataset)
-    energy_scale = np.array(dim[0][1])
+    dim = dataset.get_spectrum_dims()
+    energy_scale = np.array(dataset._axes[dim[0]])
 
     second_dif, noise_level = second_derivative(dataset, sensitivity=sensitivity)
 
@@ -489,18 +489,18 @@ def make_edges(edges_present, energy_scale, e_0, coll_angle, low_loss=None):
     edges_present: list
         list of edges
     energy_scale: numpy array
-        energy scale on which to make cross section
+        energy scale on which to make cross-section
     e_0: float
         acceleration voltage (in V)
     coll_angle: float
         collection angle in mrad
     low_loss: numpy array with same length as energy_scale
-        low_less spectrum with which to convolve the cross section (default=None)
+        low_less spectrum with which to convolve the cross-section (default=None)
 
     Returns
     -------
     edges: dict
-        dictionary with all information on cross section
+        dictionary with all information on cross-section
     """
     x_sections = get_x_sections()
     edges = {}
@@ -545,14 +545,13 @@ def make_cross_sections(edges, energy_scale, e_0, coll_angle, low_loss=None):
 
     """
     for key in edges:
-        if key.isdigit():
-            edges[key]['data'] = xsec_xrpa(energy_scale, e_0 / 1000., edges[key]['Z'], coll_angle,
+        if str(key).isdigit():
+            edges[key]['data'] = xsec_xrpa(energy_scale, e_0 / 1000., edges[key]['z'], coll_angle,
                                            edges[key]['chemical_shift']) / 1e10  # from barnes to 1/nm^2
             if low_loss is not None:
                 low_loss = np.roll(np.array(low_loss), 1024 - np.argmax(np.array(low_loss)))
                 edges[key]['data'] = scipy.signal.convolve(edges[key]['data'], low_loss/low_loss.sum(), mode='same')
 
-
             edges[key]['onset'] = edges[key]['original_onset'] + edges[key]['chemical_shift']
             edges[key]['X_section_type'] = 'XRPA'
             edges[key]['X_section_source'] = 'pyTEMlib'
@@ -989,8 +988,8 @@ def fix_energy_scale(spec, energy):
         end = startx + 2
         start = startx - 2
 
-    x = np.array(energy[start:end])
-    y = np.array(spec[start:end]).copy()
+    x = np.array(energy[int(start):int(end)])
+    y = np.array(spec[int(start):int(end)]).copy()
 
     y[np.nonzero(y <= 0)] = 1e-12
 
@@ -1055,7 +1054,7 @@ def resolution_function(energy_scale, spectrum, width, verbose=False):
 
     [p_zl, _] = leastsq(zl2, p0, args=(y, x), maxfev=2000)
     if verbose:
-        print('Fit of a Product of two Lorentzians')
+        print('Fit of a Product of two Lorentzian')
         print('Positions: ', p_zl[2], p_zl[5], 'Distance: ', p_zl[2] - p_zl[5])
         print('Width: ', p_zl[0], p_zl[3])
         print('Areas: ', p_zl[1], p_zl[4])
@@ -1219,7 +1218,7 @@ def xsec_xrpa(energy_scale, e0, z, beta, shift=0):
         chemical shift of edge in eV
     """
     beta = beta * 0.001  # collection half angle theta [rad]
-    # thetamax = self.parent.spec[0].convAngle * 0.001  # collection half angle theta [rad]
+    # theta_max = self.parent.spec[0].convAngle * 0.001  # collection half angle theta [rad]
     dispersion = energy_scale[1] - energy_scale[0]
 
     x_sections = get_x_sections(z)
@@ -1260,7 +1259,7 @@ def drude_simulation(dset, e, ep, ew, tnm, eb):
     """probabilities of dielectric function eps relative to zero-loss integral (i0 = 1)
 
     Gives probabilities of dielectric function eps relative to zero-loss integral (i0 = 1) per eV
-    Details in R.F.Egerton: EELS in the Electron Microscope, 3rd edition, Springer 2011)
+    Details in R.F.Egerton: EELS in the Electron Microscope, 3rd edition, Springer 2011
 
     # function drude(ep,ew,eb,epc,e0,beta,nn,tnm)
     # Given the plasmon energy (ep), plasmon fwhm (ew) and binding energy(eb),
@@ -1270,7 +1269,7 @@ def drude_simulation(dset, e, ep, ew, tnm, eb):
     # The output is e, ssd into the file drude.ssd (for use in Flog etc.)
     # and e,eps1 ,eps2 into drude.eps (for use in Kroeger etc.)
     # Gives probabilities relative to zero-loss integral (i0 = 1) per eV
-    # Details in R.F.Egerton: EELS in the Electron Microscope, 3rd edition, Springer 2011)
+    # Details in R.F.Egerton: EELS in the Electron Microscope, 3rd edition, Springer 2011
     # Version 10.11.26
 
 
@@ -1377,12 +1376,21 @@ def effective_collection_angle(energy_scale, alpha, beta, beam_kv):
 
     Translate from original Fortran program
     Calculates the effective collection angle in mrad:
-    Input:
-    - energy_scale : numpy array (first and last energy loss of spectrum in eV)
-    - alpha, beta: float  (collection and convergence angle in mrad)
-    - beamKV: float (acceleration voltage in V)
-    Output:
-    - effective collection angle in mrad
+    Parameter
+    ---------
+    energy_scale: numpy array
+        first and last energy loss of spectrum in eV
+    alpha: float
+        convergence angle in mrad
+    beta: float
+        collection  angle in mrad
+    beamKV: float
+        acceleration voltage in V
+
+    Returns
+    -------
+    eff_beta: float
+        effective collection angle in mrad
 
     # function y = effbeta(ene,  alpha, beta, beam_kv)
     #
@@ -1426,11 +1434,6 @@ def effective_collection_angle(energy_scale, alpha, beta, beam_kv):
     #       Universite Paris-Sud, F91405 ORSAY Cedex
     #       Phone : (33-1) 69 41 53 68
     #
-    #        real*8 pi,zx,zi,z1,z2,z3,z4,z5,z6,z7,x0,x1,x2,x3,x4,x5,x6,x7,x8
-    #        real*8 x9,x10,theta,dtheta,eta,etha2,beta
-    #        np.logical pr
-    pi = np.pi  # 3.14159;
-    #        pr=.true.               ! enable record of data
     """
     if beam_kv == 0:
         beam_kv = 100.0
@@ -1533,7 +1536,7 @@ def kroeger_core(e_data, a_data, eps_data, ee, thick, relativistic=True):
     # Calculate fixed terms of equation
     va = 1 - (511. / (511. + ee)) ** 2  # ee is incident energy in keV
     v = c * np.sqrt(va)
-    beta = v / c  # non relativistic for =1
+    beta = v / c  # non-relativistic for =1
 
     if relativistic:
         gamma = 1. / np.sqrt(1 - beta ** 2)
@@ -1678,7 +1681,7 @@ def kroeger_core2(e_data, a_data, eps_data, acceleration_voltage_kev, thickness,
     v = c * np.sqrt(va)
 
     if relativistic:
-        beta = v / c  # non relativistic for =1
+        beta = v / c  # non-relativistic for =1
         gamma = 1. / np.sqrt(1 - beta ** 2)
     else:
         beta = 1
@@ -1815,7 +1818,7 @@ def read_msa(msa_string):
     if 'XPERCHAN' in parameters:
         parameters['XPERCHAN'] = str(parameters['XPERCHAN']).split(' ')[0]
         parameters['OFFSET'] = str(parameters['OFFSET']).split(' ')[0]
-        parameters['enery_scale'] = np.arange(len(y)) * float(parameters['XPERCHAN']) + float(parameters['OFFSET'])
+        parameters['energy_scale'] = np.arange(len(y)) * float(parameters['XPERCHAN']) + float(parameters['OFFSET'])
     return parameters
 
 
